@@ -27,7 +27,8 @@ PIPE = '|'
 BACK_SLASH_SINGLE_QUOTE = "'\'"
 BACK_SLASH_DOUBLE_QUOTE = '\"'
 SLASH = '/'
-DOUBLE_SLASH = f'{2*SLASH}'
+FOWARD_SLASH = '/'
+DOUBLE_SLASH = f'{2*FOWARD_SLASH}'
 HASH_TAG = '#'
 DASH = '-'
 SPACE_DASH_SPACE = f'{SPACE}{DASH}{SPACE}'
